[![PyPi Version](https://img.shields.io/pypi/v/compmec-nurbs.svg?style=flat-square)](https://pypi.org/project/compmec-nurbs/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/compmec-nurbs.svg?style=flat-square)](https://pypi.org/project/compmec-nurbs/)
![Tests](https://github.com/compmec/nurbs/actions/workflows/tests.yml/badge.svg)

# Nurbs

This repository contains code for inteporlate functions using B-Splines and Nurbs.


# How to use it

There are some folders and inside each one, there's a README that explains how use them.

# Questions

#### Must I learn the theory to use it?

No! Just see the examples and it will be fine

#### Can I understand the code here?

Yes! The easier way is to look up the **python notebook** which contains the theory along examples

#### Is this code efficient?

No. It's written in python and the functions were made for easy understanding, not for performance.
That means: It's not very fast, but it works fine.

#### I want use it in my project. How can I do it?

For the moment, download the ```.py``` files to your project.
